@@ -20,6 +20,8 @@
 #include "global.h"
 #include "dolphindebug.h"
 
+#include "dolphin_generalsettings.h"
+
 QList<QUrl> Dolphin::validateUris(const QStringList& uriList)
 {
     QList<QUrl> urls;
@@ -33,3 +35,8 @@ QList<QUrl> Dolphin::validateUris(const QStringList& uriList)
     }
     return urls;
 }
+
+QUrl Dolphin::homeUrl()
+{
+    return QUrl::fromUserInput(GeneralSettings::homeUrl(), QString(), QUrl::AssumeLocalFile);
+}
